const parametrizacoes = require('../../model/parametrizacoes');
const Query = require('../../helpers/Query');
const Gzip = require('../../functions/Gzip');
const ServicesMonitoring = require('../../helpers/ServicesMonitoring');

const route = (router) => {
  router.put('/data/connect/portal/*', (async (req, res) => {
    try {
      const {
        ID, NOME, ORDEM,
        DESCRICAO, ATIVO,
        INTERVALO, TIPO, COMPLEMENTOTIPO 
      } = req.body;

      let { COMANDO } = req.body;
      
      if(['L', 'A'].includes(TIPO) && !Query.validate(COMANDO)) {
        throw 'INVALID_COMMAND_QUERY';
      } 
      
      if(TIPO === 'S') {
        COMANDO = ServicesMonitoring.removeMonitoringParamInconsistencies(COMANDO);
      }

      COMANDO = Gzip.encode(COMANDO);

      if (COMANDO.length > 4000) {
        throw 'MAX_CHARACTER_REACHED_COMMAND';
      }

      const result = await parametrizacoes.updateAssConfig({
        NOME,
        ORDEM,
        DESCRICAO,
        TIPO,
        ATIVO,
        COMANDO,
        INTERVALO,
        COMPLEMENTOTIPO, 
        ID,
      })

      result.connection.commit();
      res.send({
        error: false,
        message: 'SUCCESS_UPDATE_RECORD',
      });
    } catch (error) {
      res.send({
        error: false,
        message: error.message,
      });
    }
  }));

  router.delete('/data/connect/portal/*', (async (req, res) => {
    try {
      const result = await parametrizacoes.deleteAssConfig({
        ID: req.params[0]
      })

      result.connection.commit();
      res.send({
        error: false,
        message: 'SUCCESS_DELETE_RECORD',
      });
    } catch (error) {
      res.send({
        error: true,
        message: error.message,
      });
    }
  }));
}

module.exports = route;