const axios = require('axios');
const SystemLogger = require('../logs/SystemLogger');
const Base64 = require('../functions/Base64');

class AssistantControl {
  removeStartEndBar(text) {
    return text.replace(/^\/|\/+$/g, '');
  }
  getControlUrl() {
    return this.removeStartEndBar(process.env.ASSISTANT_CONTROL_URL || '');
  }
  getBasicAuth() {
    const {
      username,
      password,
    } = this.getCredentials();
    return Base64.encode(`${username}:${password}`);
  }
  getCredentials() {
    const {
      ASSISTANT_CONTROL_USERNAME: username = '',
      ASSISTANT_CONTROL_PASSWORD: password = '',
    } = process.env;
    return { username, password };
  }
  async getProductsConfig() {
    try {
      const url = `${this.getControlUrl()}/product-setting`;
      const response = await axios.get(url, {
        auth: this.getCredentials(),
      });
      return response.data;
    } catch (error) {
      SystemLogger.error(error);
      return null;
    }
  }
  getUpdateAvailableVersion() {
    const version = process.env.UPDATE_AVAILABLE_VERSION;
    return version === 'error' ? false : version;
  }

}

module.exports = new AssistantControl();